==> owncloud-10.0.7.zip: owncloud/apps/files_sharing/l10n/ast.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La compartición sirvidor a sirvidor nun ta habilitada nesti sirvidor",
    "The mountpoint name contains invalid characters." : "El puntu de montax contien caracteres non válidos",
    "Not allowed to create a federated share with the same user server" : "Nun s'almite crear un recursu compartíu federáu col mesmu usuariu de sirvidor",
    "Invalid or untrusted SSL certificate" : "Certificáu SSL inválidu o ensín validar",
    "Could not authenticate to remote share, password might be wrong" : "Nun se pudo autenticar pa compartir en remotu, quiciabes tea mal la contraseña",
    "Storage not valid" : "Almacenamientu non válidu",
    "Couldn't add remote share" : "Nun pudo amestase una compartición remota",
    "Shared with you" : "Compartíos contigo",
    "Shared with others" : "Compartíos con otros",
    "Shared by link" : "Compartíos per enllaz",
    "Uploading..." : "Xubiendo...",
    "Nothing shared with you yet" : "Entá nun compartieron nada contigo",
    "Files and folders others share with you will show up here" : "Los ficheros y carpetes que compartan contigo apaecerán equí",
    "Nothing shared yet" : "Entá nun compartíu",
    "Files and folders you share will show up here" : "Los ficheros y carpetes que compartas apaecerán equí",
    "No shared links" : "Nengún enllaz compartíu",
    "Files and folders you share by link will show up here" : "Los ficheros y carpetes que compartas por enllaz apaecerán equí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quies amestar compartición remota {name} de {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contraseña de compartición remota",
    "Cancel" : "Encaboxar",
    "Add remote share" : "Amestar compartición remota",
    "You can upload into this folder" : "Puedes xubir dientro esta carpeta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nun s'atopó nenguna instalación ownCloud (7 o cimera) en { } remotu",
    "Invalid ownCloud url" : "Url ownCloud inválida",
    "Share" : "Compartir",
    "No expiration date set" : "Nun s'afitó nenguna data de caducidá",
    "Shared by" : "Compartíos por",
    "Sharing" : "Compartiendo",
    "Share API is disabled" : "Compartir API ta deshabilitáu",
    "Wrong share ID, share doesn't exist" : "Fallu d'ID compartía, compartir nun esiste",
    "Could not delete share" : "Nun pudo desaniciase la compartición",
    "Please specify a file or folder path" : "Especifica un camín de ficheru o de carpeta",
    "Wrong path, file/folder doesn't exist" : "Camín erronéu, ficheru/carpeta nun esiste",
    "Please specify a valid user" : "Especifica un usuariu válidu",
    "Group sharing is disabled by the administrator" : "Compartir grupos ta deshabilitáu pol alministrados",
    "Please specify a valid group" : "Especifica un grupu válidu",
    "Public link sharing is disabled by the administrator" : "Compartir enllaces de forma pública ta deshabilitáu pol alministrador",
    "Public upload disabled by the administrator" : "La xubida pública ta deshabilitada pol alministrador",
    "Public upload is only possible for publicly shared folders" : "La xubida pública namás ye posible pa carpetes compartíes publicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, el formatu tien de ser YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Compartir %s falló, por cuenta qu'el backend nun dexa acciones de tipu %s",
    "Unknown share type" : "Tipu de compartición desconocíu",
    "Not a directory" : "Nun ye una carpeta",
    "Could not lock path" : "Nun pudo bloquiase'l camín",
    "Can't change permissions for public share links" : "Nun puedes camudar permisos pa enllaces públicos compartíos",
    "Wrong or no update parameter given" : "El parámetru afitáu nun ye correutu o nun ta anováu",
    "Cannot increase permissions" : "Nun se pueden aumentar los permisos",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartióse</strong> un ficheru o direutoriu",
    "A file or folder was shared from <strong>another server</strong>" : "Compartióse'l ficheru o carpeta dende <strong>otru sirvidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : " <strong>Descargóse</strong> un ficheru o carpeta pública compartida",
    "You received a new remote share %2$s from %1$s" : "Recibisti una nueva compartición remota %2$s dende %1$s",
    "You received a new remote share from %s" : "Recibisti una nueva compartición remota dende %s",
    "%1$s accepted remote share %2$s" : "%1$s aceptó compartición remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s refugó compartición remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s non compartío %2$s contigo",
    "Public shared folder %1$s was downloaded" : "Descargóse la carpeta pública compartída %1$s",
    "Public shared file %1$s was downloaded" : "Descargose'l ficheru públicu compartíu %1$s",
    "You shared %1$s with %2$s" : "Compartisti %1$s con %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartó %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Desaniciasti la compartición de %2$s por %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s desanició la compartición de %3$s por %1$s",
    "You shared %1$s with group %2$s" : "Compartisti %1$s col grupu %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartió %1$s col grupu %3$s",
    "You removed the share of group %2$s for %1$s" : "Desaniciasti la compartación del grupu %2$s por %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s desanició la compartición del grupu %3$s por %1$s",
    "%2$s shared %1$s via link" : "%2$s compartió %1$s via enllaz",
    "You shared %1$s via link" : "Compartisti %1$s per enllaz",
    "You removed the public link for %1$s" : "Desaniciasti l'enllaz públicu de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s desanició l'enllaz públicu de %1$s",
    "Your public link for %1$s expired" : "Finó l'enllaz públicu %1$s",
    "The public link of %2$s for %1$s expired" : "Finó l'enllaz públicu %2$s por %1$s",
    "%2$s shared %1$s with you" : "%2$s compartió %1$s contigo",
    "%2$s removed the share for %1$s" : "%2$s desanició la compartición de %1$s",
    "Downloaded via public link" : "Descargóse via enllaz públicu",
    "Shared with %2$s" : "Compartíu con %2$s",
    "Shared with %3$s by %2$s" : "Compartíu con  %3$s por %2$s",
    "Removed share for %2$s" : "%2$s desanició la compartición",
    "%2$s removed share for %3$s" : "%2$s desanició la compartición de %3$s",
    "Shared with group %2$s" : "Compartióse col grupu %2$s",
    "Shared with group %3$s by %2$s" : "Compartióse col grupu %3$s por %2$s",
    "Removed share of group %2$s" : "Removióse la compartición del grupu %2$s",
    "%2$s removed share of group %3$s" : "%2$s desanició la compartición del grupu %3$s",
    "Shared via link by %2$s" : "Compartióse via enllaz por %2$s",
    "Shared via public link" : "Compartióse via enllaz públicu",
    "Removed public link" : "Desaniciose l'enllaz públicu",
    "%2$s removed public link" : "%2$s removió l'enllaz públicu",
    "Public link expired" : "Finó l'enllaz públicu",
    "Public link of %2$s expired" : "Finó l'enllaz públicu de %2$s",
    "Shared by %2$s" : "Compartíu por %2$s",
    "Shares" : "Comparticiones",
    "This share is password-protected" : "Esta compartición tien contraseña protexida",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "Nenguna entrada en esta carpeta",
    "Name" : "Nome",
    "Share time" : "Compartir hora",
    "Expiration date" : "Data de caducidá",
    "Sorry, this link doesn’t seem to work anymore." : "Sentímoslo, esti enllaz paez que yá nun furrula.",
    "Reasons might be:" : "Les razones pueden ser: ",
    "the item was removed" : "desanicióse l'elementu",
    "the link expired" : "l'enllaz caducó",
    "sharing is disabled" : "la compartición ta deshabilitada",
    "For more info, please ask the person who sent this link." : "Pa más información, entrúga-y a la persona qu'unvió esti enllaz",
    "Add to your ownCloud" : "Amestar al to ownCloud",
    "Download" : "Baxar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enllaz direutu"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.1.zip: owncloud/apps/files_sharing/l10n/ast.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La compartición sirvidor a sirvidor nun ta habilitada nesti sirvidor",
    "The mountpoint name contains invalid characters." : "El puntu de montax contien caracteres non válidos",
    "Not allowed to create a federated share with the same user server" : "Nun s'almite crear un recursu compartíu federáu col mesmu usuariu de sirvidor",
    "Invalid or untrusted SSL certificate" : "Certificáu SSL inválidu o ensín validar",
    "Could not authenticate to remote share, password might be wrong" : "Nun se pudo autenticar pa compartir en remotu, quiciabes tea mal la contraseña",
    "Storage not valid" : "Almacenamientu non válidu",
    "Couldn't add remote share" : "Nun pudo amestase una compartición remota",
    "Shared with you" : "Compartíos contigo",
    "Shared with others" : "Compartíos con otros",
    "Shared by link" : "Compartíos per enllaz",
    "Uploading..." : "Xubiendo...",
    "Nothing shared with you yet" : "Entá nun compartieron nada contigo",
    "Files and folders others share with you will show up here" : "Los ficheros y carpetes que compartan contigo apaecerán equí",
    "Nothing shared yet" : "Entá nun compartíu",
    "Files and folders you share will show up here" : "Los ficheros y carpetes que compartas apaecerán equí",
    "No shared links" : "Nengún enllaz compartíu",
    "Files and folders you share by link will show up here" : "Los ficheros y carpetes que compartas por enllaz apaecerán equí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quies amestar compartición remota {name} de {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contraseña de compartición remota",
    "Cancel" : "Encaboxar",
    "Add remote share" : "Amestar compartición remota",
    "You can upload into this folder" : "Puedes xubir dientro esta carpeta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nun s'atopó nenguna instalación ownCloud (7 o cimera) en { } remotu",
    "Invalid ownCloud url" : "Url ownCloud inválida",
    "Share" : "Compartir",
    "No expiration date set" : "Nun s'afitó nenguna data de caducidá",
    "Pending" : "Pendiente",
    "Shared by" : "Compartíos por",
    "Sharing" : "Compartiendo",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartióse</strong> un ficheru o direutoriu",
    "A file or folder was shared from <strong>another server</strong>" : "Compartióse'l ficheru o carpeta dende <strong>otru sirvidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : " <strong>Descargóse</strong> un ficheru o carpeta pública compartida",
    "You received a new remote share %2$s from %1$s" : "Recibisti una nueva compartición remota %2$s dende %1$s",
    "You received a new remote share from %s" : "Recibisti una nueva compartición remota dende %s",
    "%1$s accepted remote share %2$s" : "%1$s aceptó compartición remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s refugó compartición remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s non compartío %2$s contigo",
    "Public shared folder %1$s was downloaded" : "Descargóse la carpeta pública compartída %1$s",
    "Public shared file %1$s was downloaded" : "Descargose'l ficheru públicu compartíu %1$s",
    "You shared %1$s with %2$s" : "Compartisti %1$s con %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartó %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Desaniciasti la compartición de %2$s por %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s desanició la compartición de %3$s por %1$s",
    "You shared %1$s with group %2$s" : "Compartisti %1$s col grupu %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartió %1$s col grupu %3$s",
    "You removed the share of group %2$s for %1$s" : "Desaniciasti la compartación del grupu %2$s por %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s desanició la compartición del grupu %3$s por %1$s",
    "%2$s shared %1$s via link" : "%2$s compartió %1$s via enllaz",
    "You shared %1$s via link" : "Compartisti %1$s per enllaz",
    "You removed the public link for %1$s" : "Desaniciasti l'enllaz públicu de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s desanició l'enllaz públicu de %1$s",
    "Your public link for %1$s expired" : "Finó l'enllaz públicu %1$s",
    "The public link of %2$s for %1$s expired" : "Finó l'enllaz públicu %2$s por %1$s",
    "%2$s shared %1$s with you" : "%2$s compartió %1$s contigo",
    "%2$s removed the share for %1$s" : "%2$s desanició la compartición de %1$s",
    "Downloaded via public link" : "Descargóse via enllaz públicu",
    "Shared with %2$s" : "Compartíu con %2$s",
    "Shared with %3$s by %2$s" : "Compartíu con  %3$s por %2$s",
    "Removed share for %2$s" : "%2$s desanició la compartición",
    "%2$s removed share for %3$s" : "%2$s desanició la compartición de %3$s",
    "Shared with group %2$s" : "Compartióse col grupu %2$s",
    "Shared with group %3$s by %2$s" : "Compartióse col grupu %3$s por %2$s",
    "Removed share of group %2$s" : "Removióse la compartición del grupu %2$s",
    "%2$s removed share of group %3$s" : "%2$s desanició la compartición del grupu %3$s",
    "Shared via link by %2$s" : "Compartióse via enllaz por %2$s",
    "Shared via public link" : "Compartióse via enllaz públicu",
    "Removed public link" : "Desaniciose l'enllaz públicu",
    "%2$s removed public link" : "%2$s removió l'enllaz públicu",
    "Public link expired" : "Finó l'enllaz públicu",
    "Public link of %2$s expired" : "Finó l'enllaz públicu de %2$s",
    "Shared by %2$s" : "Compartíu por %2$s",
    "Shares" : "Comparticiones",
    "Share API is disabled" : "Compartir API ta deshabilitáu",
    "Wrong share ID, share doesn't exist" : "Fallu d'ID compartía, compartir nun esiste",
    "Could not delete share" : "Nun pudo desaniciase la compartición",
    "Please specify a file or folder path" : "Especifica un camín de ficheru o de carpeta",
    "Wrong path, file/folder doesn't exist" : "Camín erronéu, ficheru/carpeta nun esiste",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, el formatu tien de ser YYYY-MM-DD",
    "Please specify a valid user" : "Especifica un usuariu válidu",
    "Group sharing is disabled by the administrator" : "Compartir grupos ta deshabilitáu pol alministrados",
    "Please specify a valid group" : "Especifica un grupu válidu",
    "Public link sharing is disabled by the administrator" : "Compartir enllaces de forma pública ta deshabilitáu pol alministrador",
    "Public upload disabled by the administrator" : "La xubida pública ta deshabilitada pol alministrador",
    "Public upload is only possible for publicly shared folders" : "La xubida pública namás ye posible pa carpetes compartíes publicamente",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Compartir %s falló, por cuenta qu'el backend nun dexa acciones de tipu %s",
    "Unknown share type" : "Tipu de compartición desconocíu",
    "Not a directory" : "Nun ye una carpeta",
    "Could not lock path" : "Nun pudo bloquiase'l camín",
    "Can't change permissions for public share links" : "Nun puedes camudar permisos pa enllaces públicos compartíos",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "This share is password-protected" : "Esta compartición tien contraseña protexida",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "Nenguna entrada en esta carpeta",
    "Name" : "Nome",
    "Share time" : "Compartir hora",
    "Expiration date" : "Data de caducidá",
    "Sorry, this link doesn’t seem to work anymore." : "Sentímoslo, esti enllaz paez que yá nun furrula.",
    "Reasons might be:" : "Les razones pueden ser: ",
    "the item was removed" : "desanicióse l'elementu",
    "the link expired" : "l'enllaz caducó",
    "sharing is disabled" : "la compartición ta deshabilitada",
    "For more info, please ask the person who sent this link." : "Pa más información, entrúga-y a la persona qu'unvió esti enllaz",
    "Download" : "Baxar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enllaz direutu"
},
"nplurals=2; plural=(n != 1);");
